==> knox-1.2.0-src.zip: knox-1.2.0/gateway-server/src/main/java/org/apache/knox/gateway/services/metrics/impl/instr/InstrGatewayFilterProviderDescriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.services.metrics.impl.instr;

import org.apache.knox.gateway.GatewayFilter;
import org.apache.knox.gateway.services.metrics.InstrumentationProvider;
import org.apache.knox.gateway.services.metrics.InstrumentationProviderDescriptor;

import java.util.HashMap;
import java.util.Map;

public class InstrGatewayFilterProviderDescriptor implements InstrumentationProviderDescriptor {

  private HashMap<Class<?>, InstrumentationProvider> providers;

  public InstrGatewayFilterProviderDescriptor() {
    providers = new HashMap<>();
    providers.put(GatewayFilter.class, new InstrGatewayFilterProvider());
  }

  @Override
  public Map<Class<?>, InstrumentationProvider> providesInstrumentation() {
    return providers;
  }
}

==> knox-2.1.0-src.zip: knox-2.1.0/gateway-server/src/main/java/org/apache/knox/gateway/services/metrics/impl/instr/InstrGatewayFilterProviderDescriptor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.knox.gateway.services.metrics.impl.instr;

import org.apache.knox.gateway.GatewayFilter;
import org.apache.knox.gateway.services.metrics.InstrumentationProvider;
import org.apache.knox.gateway.services.metrics.InstrumentationProviderDescriptor;

import java.util.HashMap;
import java.util.Map;

public class InstrGatewayFilterProviderDescriptor implements InstrumentationProviderDescriptor {

  private Map<Class<?>, InstrumentationProvider> providers;

  public InstrGatewayFilterProviderDescriptor() {
    providers = new HashMap<>();
    providers.put(GatewayFilter.class, new InstrGatewayFilterProvider());
  }

  @Override
  public Map<Class<?>, InstrumentationProvider> providesInstrumentation() {
    return providers;
  }
}
